# 6 Mistakes Organizations Make When Deploying Advanced Authentication
## Advanced authentication: The key to addressing the weakest link in cybersecurity - human users. Learn how to fortify your organization's defenses.
## Information:

+ Link: https://thehackernews.com/2024/05/6-mistakes-organizations-make-when.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 14 May 2024, 16:21
+ Date scraped: 14 May 2024, 11:09

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjLFi5vwgPwmrKgIafhE-_gG3voXLQC3RGTK0MFU0pxOFmqlOekYX5kOJ2W4RUqmzsSgjQpgnIHbpZJAbZB3L-_8h1bKkDMAy29F47szXCvmzdY1gutG3rqEoD3ETmNDpktqkntOGN7_FRzw-Kh3HogU0g4Rk5k9rurEga5551q3K2pXVGELQwMOPJbyiY/s728-rw-e365/ONE.png)


Deploying advanced authentication measures is key to helping organizations address their weakest cybersecurity link: their human users. Having some form of 2-factor authentication in place is a great start, but many organizations may not yet be in that spot or have the needed level of authentication sophistication to adequately safeguard organizational data. When deploying advanced authentication measures, organizations can make mistakes, and it is crucial to be aware of these potential pitfalls.


1. Failing to conduct a risk assessment[#](#1-failing-to-conduct-a-risk-assessment)
-----------------------------------------------------------------------------------


A comprehensive risk assessment is a vital first step to any authentication implementation. An organization leaves itself open to risk if it fails to assess current threats and vulnerabilities, systems and processes or needed level of protections required for different applications and data.


Not all applications demand the same levels of security. For example, an application that handles sensitive customer information or financials may require stronger authentication measures compared to less critical systems. Without a risk assessment, organizations won't be able to effectively categorize and prioritize what needs additional authentication.


Hence, the a need for **[elevating organizational security with advanced authentication](https://www.onelogin.com/resource-center/techbriefs/elevating-organizational-security-with-advanced-authentication)**.


On top of that, not all users need access to all applications or data. For example, a user in marketing doesn't need access to sensitive HR data. By evaluating roles as part of a risk assessment, organizations can look to implement role-based access controls (RBAC) which ensure that users in a particular role only have access to the data and applications needed to complete their work.


2. Not completing due diligence to integrate authentication with current systems[#](#2-not-completing-due-diligence-to-integrate-authentication-with-current-systems)
---------------------------------------------------------------------------------------------------------------------------------------------------------------------


Considering compatibility with existing systems, especially legacy ones, is essential to ensure a cohesive authentication framework across an entire infrastructure. Adhering to industry-standard authentication methods is crucial. This may involve recoding application frontends to adopt OIDC (OpenID Connect) or [SAML (Security Assertion Markup Language)](https://www.onelogin.com/learn/saml) flows. Many vendors offer toolkits that simplify this process to help ensure seamless integration. 


Doing due diligence to make sure your systems have integration options with an authentication system helps to reduce implementation complexity and enhances overall security.


3. Requiring only one authentication factor[#](#3-requiring-only-one-authentication-factor)
-------------------------------------------------------------------------------------------


Requiring at least two authentication factors is imperative in today's security landscape. A selection of recommended additional factors include:


* Physical tokens: Devices like Yubikey or Google Titan tokens generate digital signatures that offer another layer of identity security
* [Biometric authentication](https://www.onelogin.com/learn/biometric-authentication): Factors like fingerprints or facial recognition
* Trusted devices: Device enrollment or the presence of an issued and verified certificate ensures that the users we know are using trusted devices and can access the systems they need
* High Trust factors such as BankID or Government e-ID


Consider data sensitivity when choosing authentication factors. For highly sensitive information, a combination of multiple factors can offer higher levels of security. However, access to less sensitive data may be granted with just a password and a time-based-one-time-password (TOTP) authenticator app code or PUSH notification.


Another option to explore would be [passwordless authentication](https://www.onelogin.com/learn/passwordless-authentication). Instead of a password, this option leverages other authentication factors like biometrics, trusted devices or physical tokens to grant access. 


Reyling on one authentication factor is not enough to effectively combat the evolving threats facing organizations.


4. Forgetting about user experience[#](#4-forgetting-about-user-experience)
---------------------------------------------------------------------------


If a user's authentication flow is too unwieldy and cumbersome, users will become frustrated. Balancing security and accessibility is crucial for a positive user experience. When considering advanced authentication factors, prioritize solutions that minimize steps and reduce friction. Clear instructions, user-friendly interfaces and self-service options enhance the user experience.


5. Not paying attention to authentication activities and patterns[#](#5-not-paying-attention-to-authentication-activities-and-patterns)
---------------------------------------------------------------------------------------------------------------------------------------


Without regular review or insights into user behaviors, organizations won't be able to effectively assess or mitigate risks. Regular monitoring and analysis of authentication activities are essential to ensure ongoing security.


While most Identity and Access Management (IAM) platforms offer logging data and dashboards, real-time alerts to suspicious or abnormal behavior through SIEM integrations allow organizations to quickly identify threats and take action. These alerts notify admins and security teams of unauthorized access attempts via unusual login patterns.


Some organizations implement risk-based authentication, which leverages machine learning to develop a profile of past login behavior and adjusts security measures to verify user identity in real-time. Login attempts with elevated risk scores are required to provide additional authentication factors or are denied access entirely, while lower risk logins are prompted with fewer requirements or bypass authentication altogether.


6. Neglecting to train and educate users[#](#6-neglecting-to-train-and-educate-users)
-------------------------------------------------------------------------------------


Training users is essential for enhancing overall security. Otherwise, users may engage in risky behaviors that put the organization in a more vulnerable position.


Effective end-user training involves providing clear, user-friendly documentation on setting up and using advanced authentication methods. This documentation should offer step-by-step instructions, screenshots and troubleshooting tips for easy understanding and enrollment. Additionally, highlighting real-world examples and case studies of security breaches can bring heightened awareness to potential consequences.


Promoting a culture of security awareness and vigilance allows organizations to instill a sense of responsibility among users and encourages proactive participation in authentication.


By avoiding these mistakes, organizations can significantly enhance their security posture, reduce the risk of unauthorized access or data breaches and further protect valuable company assets.


  





## Tags:


### Autogenerated tags:

