# Maximum-severity GitLab flaw allowing account hijacking under active exploitation
## The threat is potentially grave because it could be used in supply chain attacks.
## Information:

+ Link: https://arstechnica.com/security/2024/05/0-click-gitlab-hijacking-flaw-under-active-exploit-with-thousands-still-unpatched/
+ Source: Ars Technica
+ Author: Dan Goodin
+ Date published: 02 May 2024, 19:02
+ Date scraped: 02 May 2024, 20:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/07/exploit-vulnerability-security-760x380.jpg)



A maximum severity vulnerability that allows hackers to hijack GitLab accounts with no user interaction required is now under active exploitation, federal government officials warned as data showed that thousands of users had yet to install a patch released in January.


A change GitLab implemented in May 2023 made it possible for users to initiate password changes through links sent to secondary email addresses. The move was designed to permit resets when users didn’t have access to the email address used to establish the account. In January, GitLab [disclosed](https://about.gitlab.com/releases/2024/01/11/critical-security-release-gitlab-16-7-2-released/) that the feature allowed attackers to send reset emails to accounts they controlled and from there click on the embedded link and take over the account.


While exploits require no user interaction, hijackings work only against accounts that aren’t configured to use multifactor authentication. Even with MFA, accounts remained vulnerable to password resets, but the attackers ultimately are unable to access the account, allowing the rightful owner to change the reset password. The vulnerability, tracked as CVE-2023-7028, carries a severity rating of 10 out of a possible 10.


On Wednesday, the US Cybersecurity and Infrastructure Security Agency [said](https://www.cisa.gov/news-events/alerts/2024/05/01/cisa-adds-one-known-exploited-vulnerability-catalog) it is aware of “evidence of active exploitation” and added the vulnerability to its list of known exploited vulnerabilities. CISA provided no details about the in-the-wild attacks. A GitLab representative declined to provide specifics about the active exploitation of the vulnerability.


The vulnerability, classified as an improper access control flaw, could pose a grave threat. GitLab software typically has access to multiple development environments belonging to users. With the ability to access them and surreptitiously introduce changes, attackers could sabotage projects or plant backdoors that could infect anyone using software built in the compromised environment. An example of a similar supply chain attack is the one that hit [SolarWinds in 2021](https://arstechnica.com/information-technology/2020/12/russian-hackers-hit-us-government-using-widespread-supply-chain-attack/), infecting more than [18,000 of its customers](https://arstechnica.com/information-technology/2020/12/18000-organizations-downloaded-backdoor-planted-by-cozy-bear-hackers/). Other recent examples of supply chain attacks are [here](https://arstechnica.com/information-technology/2023/03/massive-supply-chain-attack-with-ties-to-north-korea-hits-users-of-3cx-voice-app/), [here](https://arstechnica.com/gadgets/2021/07/up-to-1500-businesses-infected-in-one-of-the-worst-ransomware-attacks-ever/), and [here](https://arstechnica.com/gadgets/2021/04/backdoored-developer-tool-that-stole-credentials-escaped-notice-for-3-months/).
These sorts of attacks are powerful. By hacking a single, carefully selected target, attackers gain the means to infect thousands of downstream users, often without requiring them to take any action at all.


According to Internet scans performed by security organization Shadowserver, more than 2,100 IP addresses showed they were hosting one or more vulnerable GitLab instances.


[![](https://cdn.arstechnica.net/wp-content/uploads/2024/05/cve-2023-7028-week-view-640x375.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/05/cve-2023-7028-week-view-scaled.jpg)Shadowserver


The biggest concentration of IP addresses was in India, followed by the US, Indonesia, Algeria, and Thailand.


[![](https://cdn.arstechnica.net/wp-content/uploads/2024/05/cve-2023-7028-by-country-640x294.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/05/cve-2023-7028-by-country-scaled.jpg)Shadowserver


The number of IP addresses showing vulnerable instances has fallen over time. Shadowserver shows that there were more than 5,300 addresses on January 22, one week after GitLab issued the patch.


[![](https://cdn.arstechnica.net/wp-content/uploads/2024/05/cve-2023-2708-4-month-view-640x322.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/05/cve-2023-2708-4-month-view-scaled.jpg)Shadowserver


The vulnerability is classed as an improper access control flaw.


CISA has ordered all civilian federal agencies that have yet to patch the vulnerability to do so immediately. The agency made no mention of MFA, but any GitLab users who haven’t already done so should enable it, ideally with a form that complies with the [FIDO](https://fidoalliance.org/) industry standard.


GitLab users should also remember that patching does nothing to secure systems that have already been breached through exploits. GitLab has published incident response guidance [here](%E2%80%8B%E2%80%8Bhttps://docs.gitlab.com/ee/security/responding_to_security_incidents.html#suspected-compromised-user-account).





## Tags:
***CVE's***: CVE-2023-7028

### Autogenerated tags:
[[gitlab]] [[shadowserver]] [[ip]]
