# Linksys EA7500 Routers Flaw Let Attackers Execute Remote Code
## A severe security vulnerability has been identified in the Linksys EA7500 routers, affecting the model's firmware across all versions.
## Information:

+ Link: https://cybersecuritynews.com/?p=64563
+ Source: Cyber Security News
+ Author: Dhivya
+ Date published: 14 May 2024, 10:58
+ Date scraped: 14 May 2024, 11:10

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEh-E9NWTQim2ONs5A9Go1volVvABEYhK-gPVvyGUARmFkwSSBJz0db21VGAnNlZqA6_S2Ueb_toBPEQDYM_EEpdtPkPVKeJmXud5z2Mp9JxqzNaqH3Fz8S-QkvpkG9O9StOSr0h1X47eqC1EQDxDfwKEF2pKgP4LhAl3g2IK3yySNFM1SWepf3oZuKaXbg/s1600/Linksys%20EA7500%20Routers%20Flaw%20(1).webp)


A severe security vulnerability has been identified in the Linksys EA7500 routers, specifically affecting the model’s firmware across all versions, including the latest Ver.3.0.1.207964.


This flaw, if exploited, allows [attackers](https://cybersecuritynews.com/next-js-server-compromise/) with network adjacency to execute arbitrary code on the device without requiring authentication, posing a significant risk to users’ network security.


**[CVE-2023-46012](https://nvd.nist.gov/vuln/detail/CVE-2023-46012): Remote Code Execution Vulnerability**
----------------------------------------------------------------------------------------------------------


The vulnerability resides in the handling of HTTP request data by the Internet Gateway Device (IGD) Universal Plug and Play (UPnP) service of the routers, as [reported](https://www.linksys.com/support-article?articleNum=49798) by Linksys. 


`Free Webinar on **[Live API Attack Simulation](https://www.indusface.com/live-api-attack-simulation.php?utm_source=blog-cta&utm_medium=referral&utm_campaign=2024-may-webinar-live-api-attack-simulation)**: Book Your Seat | Start protecting your APIs from hackers`


The flaw is triggered during the processing of a SOAP UPnP Action Request, where the router fails to adequately validate the length of user-supplied data before copying it to a fixed-length stack buffer.


**Vulnerable Function: SetDefaultConnectionService**
----------------------------------------------------


The critical function at the heart of this vulnerability is, identified internally as \_set\_connection\_type.


This function initializes an 184-byte buffer and attempts to handle a user-supplied string variable. It does this by calling PAL\_xml\_node\_GetFirstbyName and then PAL\_xml\_node\_get\_value.


**See the code below:**



```
int _set_connection_type(int **param_1)

{

  int iVar1;

  char *var_value;

  size_t var_value_length;

  undefined uVar2;

  undefined1 *puVar3;

  char **ppcVar4;

  undefined4 *puVar5;

  char *pcVar6;

  int *piVar7;

  char acStack_d4 [184]; -----> /* Initializing 184-byte buffer */

  memset(acStack_d4,0,0xb4);

  iVar1 = PAL_xml_node_GetFirstbyName((*param_1)[0xf0],"NewConnectionType",0); -----> /* iVar1 now points to the user-supplied value */

  if ((iVar1 != 0) && (var_value = (char *)PAL_xml_node_get_value(), var_value != (char *)0x0)) { -----> /* Ensures the user-supplied value is not empty and obtains a pointer to it */

  ...
```

However, an overly long string can lead to a buffer overflow due to improper validation.


This condition is exacerbated by the use of the `strncpy` function, which does not ensure null termination or check the size of the destination buffer, allowing an attacker to overwrite critical memory areas and potentially [hijack](https://cybersecuritynews.com/hijackloader-png-malware/) the program’s control flow.


**See the code below:**



```
int _set_connection_type(int **param_1)

{

 ...

      var_value_length = strlen((char *)(iVar1 + 0x174)); ----> /* iVar1 is a pointer to the user supplied string */

      strncpy(acStack_d4,(char *)(iVar1 + 0x174),var_value_length + 1); ----> /* Vulnerable strncpy call */

 ...
```

An attacker can trigger the buffer overflow by crafting a malicious HTTP request with an oversized string variable.


The specific vulnerability allows the overwriting of a function return address on the stack, enabling redirection of execution to arbitrary addresses controlled by the attacker.


This could lead to unauthorized code execution with root privileges, compromising the entire device.


The Linksys EA7500 router users are urged to monitor the Linksys support page for firmware updates addressing this vulnerability.


Given the flaw’s severity, it is critical to apply security patches as soon as they become available to prevent potential [exploits.](https://cybersecuritynews.com/blueducky-exploits-bluetooth-vulnerability/)





## Tags:
***CVE's***: CVE-2023-46012

### Autogenerated tags:
[[ivar1]] [[linksys]] [[user-supplied]] [[_set_connection_type]] [[strncpy]]
