# Linux Kernel Vulnerability (CVE-2024-26925) Let Hackers Access Unauthorized Data
## In a significant update from the Linux kernel's security team, a critical vulnerability identified as CVE-2024-26925 has been addressed.
## Information:

+ Link: https://cybersecuritynews.com/?p=63468
+ Source: Cyber Security News
+ Author: Balaji N
+ Date published: 30 April 2024, 07:51
+ Date scraped: 30 April 2024, 10:08

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjv-z4UA2c_i-6Qtj9TfH08YpDwiCoytqw7rlhnkHhlr7Fa-kNhVhzz5sDbf_ReFJtktN2Kdm5akVuhTs9oCBxOl2aQo3Ndbiu0Xn62s_O1mZHmrJ84yt88jvCCpah8KYt4YZMdA2y9EIUCy_xLmsqRENeDRrvJ5da7UCFCBAysozQR8KXOfHQdin6bq4HG/s16000/linux%20kernal%20vulnerbility.webp)


In a significant update from the Linux kernel’s security team, a critical vulnerability identified as CVE-2024-26925 has been addressed to bolster the security of systems worldwide.


The flaw was found in the netfilter subsystem, specifically within the nf\_tables component, which is crucial for packet filtering and classification.


**Description of the Vulnerability**
------------------------------------


The vulnerability stemmed from improperly releasing a mutex within the [garbage collection](https://googleprojectzero.blogspot.com/2022/08/the-quantum-state-of-linux-kernel.html#:~:text=During%20the%20garbage%20collection%20process%2C%20f%2000%20and%20f,01's%20receive%20queue.) (GC) sequence of nf\_tables. 


Typically, the commit mutex should remain locked during the critical section between `nft_gc_seq_begin()` and `nft_gc_seq_end()` to prevent asynchronous GC workers from collecting expired objects and acquiring the released commit lock within the same GC sequence.


However, it was [discovered](https://lore.kernel.org/linux-cve-announce/2024042421-CVE-2024-26925-7c19@gregkh/T/#u) that `nf_tables_module_autoload()` was temporarily releasing the mutex to load module dependencies, then reacquiring it to replay the transaction. This incorrect handling could potentially lead to race conditions, jeopardizing the stability and security of the Linux kernel.


The issue was rectified by modifying the mutex release sequence. Now, the mutex release occurs at the end of the abort phase after `nft_gc_seq_end()` is called, ensuring that GC workers protect the critical section from concurrent access. 


Greg Kroah-Hartman, a renowned kernel maintainer, committed this change to the Linux kernel source under the patch identifier CVE-2024-26925.


In the commit message, Greg Kroah-Hartman, explained, “The commit mutex should not be released during the critical section between nft\_gc\_seq\_begin() and nft\_gc\_seq\_end(). Otherwise, the async GC worker could collect expired objects and get the released commit lock within the same GC sequence.”


The vulnerability could affect many systems, particularly those utilizing the nf\_tables for network packet filtering.


By resolving this issue, the Linux kernel developers have prevented possible exploits that could lead to system crashes or unauthorized data access.


**`Is Your Network Under Attack? - Read CISO’s Guide to Avoiding the Next Breach - [Download Free Guide](https://www.perimeter81.com/whitepapers/ciso-avoid-breach?utm_source=gbhackers&utm_medium=affiliate&utm_campaign=top_articles_gbchakers_cisos_wp&a_aid=2428)`**


**Mitigation and Recommendations**
----------------------------------


The Linux kernel CVE team strongly advises users to update to the latest stable kernel version, which includes this patch among other bug fixes. The team emphasizes that individual changes are not tested in isolation but as part of the entire kernel release.


Therefore, cherry-picking individual commits is discouraged and unsupported.


For the most current information regarding which kernel versions remain unaffected as fixes are backported, users are encouraged to consult the official CVE entry at [CVE-2024-26925 on cve.org](https://cve.org/CVERecord/?id=CVE-2024-26925).


This proactive patching underscores the Linux community’s commitment to security and stability. Users and administrators are urged to apply the latest updates to safeguard their systems against potential threats stemming from this vulnerability.





## Tags:
***CVE's***: CVE-2024-26925

### Autogenerated tags:
[[linux]] [[mutex]] [[gc]] [[cve-2024-26925]] [[nf_tables]] [[nft_gc_seq_end]]
