# Citrix warns customers to update PuTTY version installed on their XenCenter system manually
## Citrix urges customers to manually address a PuTTY SSH client flaw that could allow attackers to steal a XenCenter admin's private SSH key.
## Information:

+ Link: https://securityaffairs.com/162953/security/citrix-manually-update-putty-ssh-client.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 10 May 2024, 05:23
+ Date scraped: 10 May 2024, 07:11

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2019/03/Citrix.png)



Versions of XenCenter for Citrix Hypervisor 8.2 CU1 LTSR used PuTTY, a third-party component, for SSH connections to guest VMs. However, PuTTY inclusion was deprecated with XenCenter version 8.2.6, and any versions after 8.2.7 will not include PuTTY.


The security flaw, tracked as [CVE-2024-31497](https://securityaffairs.com/161921/security/putty-ssh-client-flaw.html), affects multiple versions of XenCenter for Citrix Hypervisor 8.2 CU1 LTSR, which includes PuTTY.



The flaw resides in the code that generates signatures from ECDSA private keys which use the NIST P521 curve. An attacker can exploit the vulnerability to recover NIST P-521 private keys.


*“An issue has been reported in versions of PuTTY prior to version 0.81; when used in conjunction with XenCenter, this issue may, in some scenarios, allow an attacker who controls a guest VM to determine the SSH private key of a XenCenter administrator who uses that key to authenticate to that guest VM while using an SSH connection.” [reads the advisory](https://support.citrix.com/article/CTX633416/citrix-hypervisor-security-update-for-cve202431497).*


The company recommends customers who do not want to use the “Open SSH Console” functionality to remove the PuTTY component.  Customers who wish to use the functionality should replace the PuTTY version installed on their XenCenter system with an updated version (with a version number of at least 0.81).


The vulnerability [CVE-2024-31497](https://securityaffairs.com/161921/security/putty-ssh-client-flaw.html) was discovered by researchers Fabian Bäumer and Marcus Brinkmann from the Ruhr University Bochum. Bäumer explained that the vulnerability stems from the generation of biased ECDSA cryptographic nonces, which could allow full secret key recovery.


*“The PuTTY client and all related components generate heavily biased ECDSA nonces in the case of NIST P-521. To be more precise, the first 9 bits of each ECDSA nonce are zero. This allows for full secret key recovery in roughly 60 signatures by using state-of-the-art techniques. These signatures can either be harvested by a malicious server (man-in-the-middle attacks are not possible given that clients do not transmit their signature in the clear) or from any other source, e.g. signed git commits through forwarded agents.” [Baumer explained](https://seclists.org/oss-sec/2024/q2/122). “The nonce generation for other curves is slightly biased as well. However, the bias is negligible and far from enough to perform lattice-based key recovery attacks (not considering cryptanalytical advancements).”*


The following products include an affected PuTTY version and are therefore are also impacted by the flaw:


* FileZilla (3.24.1 – 3.66.5)
* WinSCP (5.9.5 – 6.3.2)
* TortoiseGit (2.4.0.2 – 2.15.0)
* TortoiseSVN (1.10.0 – 1.14.6)


The flaw has been fixed in PuTTY 0.81, FileZilla 3.67.0, WinSCP 6.3.3, and TortoiseGit 2.15.0.1. TortoiseSVN users are recommended to configure TortoiseSVN to use Plink from the latest PuTTY 0.81 release when accessing a SVN repository via SSH until a patch becomes available.


Any product or component using ECDSA NIST-P521 keys impacted by the flaw [**CVE-2024-31497**](https://nvd.nist.gov/vuln/detail/CVE-2024-31497) should be deemed compromised. These keys should be revoked by removing them from authorized\_keys, GitHub repositories, and any other relevant platforms.


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [Mastodon](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, Citrix)**





---




---





## Tags:
***CVE's***: CVE-2024-31497
***ipv4-adresses***: 2.4.0.2

### Autogenerated tags:
[[xencenter]] [[ssh]] [[ecdsa]] [[citrix]] [[cve-2024-31497]] [[tortoisesvn]]
