# CISA, FBI Urge Organizations to Eliminate Path Traversal Vulnerabilities
## CISA and the FBI warn of threat actors abusing path traversal software vulnerabilities in attacks targeting critical infrastructure.
## Information:

+ Link: https://www.securityweek.com/cisa-fbi-urge-organizations-to-eliminate-path-traversal-vulnerabilities/
+ Source: SecurityWeek
+ Author: Ionut Arghire
+ Date published: 03 May 2024, 11:43
+ Date scraped: 03 May 2024, 12:01

## Article:
![Main article image](https://www.securityweek.com/wp-content/uploads/2023/01/Cybersecurity_News-SecurityWeek.jpg)


**The US cybersecurity agency CISA and the FBI on Thursday released a Secure by Design Alert warning of path traversal software vulnerabilities being exploited in attacks targeting critical infrastructure entities.**


Also known as directory traversal, path traversal flaws rely on manipulated user input to access application files and directories that should not be accessible. Successful exploitation allows threat actors to manipulate arbitrary files, read sensitive data, and potentially fully compromise the system.

Documented for over two decades and deemed ‘unforgivable’ in 2007, path traversal defects remain a persistent class of bugs in software, with at least two recent issues exploited against critical infrastructure sectors, including healthcare and public health organizations.

In response to the exploitation of the two vulnerabilities – which impact ConnectWise ScreenConnect ([CVE-2024-1708](https://www.securityweek.com/slashandgrab-screenconnect-vulnerability-widely-exploited-for-malware-delivery/)) and Cisco AppDynamics Controller ([CVE-2024-20345](https://www.securityweek.com/cisco-raises-alarm-for-arcanedoor-zero-days-hitting-asa-firewall-platforms/)) – CISA and the FBI are [urging organizations](https://www.cisa.gov/sites/default/files/2024-05/Secure_by_Design_Alert_Eliminating_Directory_Traversal_Vulnerabilities_in_Software_508c%20%283%29.pdf) (PDF) to ensure their software developers eliminate this class of security defects.


CISA currently lists 55 path traversal flaws in its Known Exploited Vulnerabilities (KEV) Catalog.

The two US government agencies underline that a secure by design software development lifecycle is the base for eliminating security holes, including path traversal flaws, as products are built in a way that reasonably protects them from bug exploitation.

“Incorporating this risk mitigation at the outset—beginning in the design phase and continuing through product release and updates—reduces both the burden of cybersecurity on customers and risk to the public,” CISA and the FBI note.

Well-known and effective mitigations include using random identifiers for files and storing metadata separately, or limiting the number of characters in file names and ensuring that uploaded files do not have execution permissions.


[OWASP’s guidance](https://owasp.org/www-community/attacks/Path_Traversal) on path traversal flaws includes additional mitigations that both software manufacturers and cloud services operators are advised to review and implement.


Additionally, organizations are advised to test products against path traversal bugs and protect themselves against their exploitation by adhering to the three principles detailed in the [secure by design guidance](https://www.cisa.gov/resources-tools/resources/secure-by-design) published in October 2023.


By fully implementing the recommended secure by design principles and practices, software manufacturers can protect their customers from a wide range of malicious attacks, the two agencies say.

“Further, CISA and the FBI urge manufacturers to publish their own secure by design roadmap to demonstrate that they are not simply implementing tactical controls but are strategically rethinking their responsibility in keeping customers safe,” CISA and the FBI note.

**Related:** [Federal Push for Secure-by-Design: What It Means for Developers](https://www.securityweek.com/federal-push-for-secure-by-design-what-it-means-for-developers/)


**Related:** [CISA Debuts ‘Secure by Design’ Alert Series](https://www.securityweek.com/cisa-debuts-secure-by-design-alert-series/)


**Related:** [CISA Introduces Secure-by-design and Secure-by-default Development Principles](https://www.securityweek.com/cisa-introduces-secure-by-design-and-secure-by-default-development-principles/)





## Tags:
***CVE's***: CVE-2024-1708 CVE-2024-20345

### Autogenerated tags:
[[cisa]]
