# Critical Flaws in Cacti Framework Could Let Attackers Execute Malicious Code
## 12 security flaws addressed, including two critical issues leading to remote code execution. Update to version 1.2.27 now to stay protected
## Information:

+ Link: https://thehackernews.com/2024/05/critical-flaws-in-cacti-framework-could.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 14 May 2024, 16:47
+ Date scraped: 14 May 2024, 12:09

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiHLObaDDW6hdIpLGFNDDk2sYbQB81_DFHKufB40rUMtjWDIHnxm6KFsECxwXCMaSXiZNYt11Oqp_5iWn7F6THWOMJPE2HZLD1jjV5t20PcFyEG_IyW9sWX00AsLPlfT-XhA00tSyHjNdwe1NjptEAWja1IH6HUuMGJAihrs6Y9sjQbAeUTH24vfCQ-Medf/s728-rw-e365/catci.png)


The maintainers of the [Cacti](https://www.cacti.net/) open-source network monitoring and fault management framework have addressed a dozen security flaws, including two critical issues that could lead to the execution of arbitrary code.


The most severe of the vulnerabilities are listed below -


* **[CVE-2024-25641](https://github.com/Cacti/cacti/security/advisories/GHSA-7cmj-g5qc-pj88)** (CVSS score: 9.1) - An arbitrary file write vulnerability in the "Package Import" feature that allows authenticated users having the "Import Templates" permission to execute arbitrary PHP code on the web server, resulting in remote code execution


* **[CVE-2024-29895](https://github.com/Cacti/cacti/security/advisories/GHSA-cr28-x256-xf5m)** (CVSS score: 10.0) - A command injection vulnerability allows any unauthenticated user to execute arbitrary command on the server when the "[register\_argc\_argv](https://www.php.net/manual/en/ini.core.php#ini.register-argc-argv)" option of PHP is On


[![Cacti Framework](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiAlHNVC6KF18UDgq22mDKpwU5HfCWq21eBR3yc86eiI63lV2JZndpFXnCmz8Zd6YkFBD825CcG4HCC-TAN8X-9dNYBQ-tGReLdH69_CuUncn8cTxcgB8Me_3MvR6spumBsteYWP6r_B-yBX7OjVUYHbQYwV6ZO0XTO8Jheo9qlv_QwRbG3wqNWGztFj_6O/s728-rw-e365/exploit.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiAlHNVC6KF18UDgq22mDKpwU5HfCWq21eBR3yc86eiI63lV2JZndpFXnCmz8Zd6YkFBD825CcG4HCC-TAN8X-9dNYBQ-tGReLdH69_CuUncn8cTxcgB8Me_3MvR6spumBsteYWP6r_B-yBX7OjVUYHbQYwV6ZO0XTO8Jheo9qlv_QwRbG3wqNWGztFj_6O/s728-rw-e365/exploit.png)
Also addressed by Cacti are two other high-severity flaws that could lead to code execution via SQL injection and file inclusion -


* **[CVE-2024-31445](https://github.com/Cacti/cacti/security/advisories/GHSA-vjph-r677-6pcc)** (CVSS score: 8.8) - An SQL injection vulnerability in api\_automation.php that allows authenticated users to perform privilege escalation and remote code execution


* **[CVE-2024-31459](https://github.com/Cacti/cacti/security/advisories/GHSA-cx8g-hvq8-p2rv)** (CVSS score: N/A) - A file inclusion issue in the "lib/plugin.php" file that could be combined with SQL injection vulnerabilities to result in remote code execution


It's worth noting that 10 out of the 12 flaws, with the exception of CVE-2024-29895 and [CVE-2024-30268](https://github.com/Cacti/cacti/security/advisories/GHSA-9m3v-whmr-pc2q) (CVSS score: 6.1), impact all versions of Cacti, including and prior to 1.2.26. They have been addressed in [version 1.2.27](https://github.com/Cacti/cacti/releases/tag/release%2F1.2.27) released on May 13, 2024. The two other flaws affect the development versions 1.3.x.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg_WRs2jRYPNRPdVnIJ52g0Zo3TY_c0FSwk8ZZN085hqm-nXig4b7WIZCpqdHexadU4EmZ402vX1EghcAxIZGa9lwLkWAPPYzPbg1gc5UZCbvTtOHQ3ozwiQAgJ1ahKFoOp8SZl-JN8_URGwiu9aTe5U2wiVHGEetM-S7kKkmgPMNdL_83d5HTJrLm7iBp6/s728-e365/cis-d.png)](https://thehackernews.uk/cis-hardened-images)
The development comes more than eight months after the disclosure of another critical SQL injection vulnerability ([CVE-2023-39361](https://github.com/Cacti/cacti/security/advisories/GHSA-6r43-q2fw-5wrg), CVSS score: 9.8) that could permit an attacker to obtain elevated permissions and execute malicious code. 


In early 2023, a third critical flaw tracked as [CVE-2022-46169](https://thehackernews.com/2023/01/cacti-servers-under-attack-as-majority.html) (CVSS score: 9.8) came under active exploitation in the wild, allowing threat actors to breach internet-exposed Cacti servers to deliver botnet malware such as [MooBot and ShellBot](https://thehackernews.com/2023/04/cacti-realtek-and-ibm-aspera-faspex.html).


With proof-of-concept (PoC) exploits publicly available for these shortcomings (in the respective GitHub advisories), it's recommended that users take steps to update their instances to the latest version as soon as possible to mitigate potential threats.

 
  





## Tags:
***CVE's***: CVE-2024-25641 CVE-2022-46169 CVE-2024-31445 CVE-2024-30268 CVE-2023-39361 CVE-2024-29895 CVE-2024-31459

### Autogenerated tags:
[[cvss]] [[sql]]
