# Sandbox Escape Vulnerabilities in Judge0 Expose Systems to Complete Takeover
## Multiple vulnerabilities have been discovered in the popular Judge0 online code execution system, putting users at risk of complete system compromise.
## Information:

+ Link: https://thehackernews.com/2024/04/sandbox-escape-vulnerabilities-in.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 29 April 2024, 15:28
+ Date scraped: 29 April 2024, 10:08

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjppN76NCl4VWJWx9vC62a5UJWg6_8941jN40G4LoUaca6Urq6e7j7H_QtxIB06N_ZFQFaoEgSVhwlsqYzsArwt70PlPicfIwFwgkrGO7bGw_0vJOV2Nsn3Q7CP6xzhRFhpDo_N5_N-BJhLlifM5y17HDA6wac2K6hqEwrJ0AvrALHT1l_6QL0KKYz8uAeN/s728-rw-e365/sandbox.png)


Multiple critical security flaws have been disclosed in the Judge0 open-source online code execution system that could be exploited to obtain code execution on the target system.


The three flaws, all critical in nature, allow an "adversary with sufficient access to perform a sandbox escape and obtain root permissions on the host machine," Australian cybersecurity firm Tanto Security said in a report[report](https://tantosec.com/blog/judge0/) published today.


Judge0 (pronounced "judge zero") is [described](https://judge0.com/) by its maintainers as a "robust, scalable, and open-source online code execution system" that can be used to build applications that require online code execution features such as candidate assessment, e-learning, and online code editors and IDEs.


According to its website, the service is used by 23 customers like AlgoDaily, CodeChum, and PYnative, among others. The project has been [forked 412 times on GitHub](https://github.com/judge0/judge0) to date.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiuUUskkMH9dUT3LF77_Q_irGuaE4LGjp-Am2Ls_UzGJ5EBnZHfuFiSvKs4OPE5KmfedBHcuZZVHS4Bh48UJx8brpwtg6Vr2Gepbaw-lGMIm9HjUhyphenhyphen2W5DVm5-ymwPS691Ie32TrCqFIv6SxNRA-jOKCKZrOB5dV7BfL0zVAhOO0neNkP9yv-XePBU1hN_0/s728-e365/wing-d.png)](https://thehackernews.uk/third-party-risk-management-saas)
The flaws, discovered and reported by Daniel Cooper in March 2024, are listed below -


* **[CVE-2024-28185](https://github.com/judge0/judge0/security/advisories/GHSA-h9g2-45c8-89cf)** (CVSS score: 10.0) - The application does not account for symlinks placed inside the sandbox directory, which can be leveraged by an attacker to write to arbitrary files and gain code execution outside of the sandbox.


* **[CVE-2024-28189](https://github.com/judge0/judge0/security/advisories/GHSA-3xpw-36v7-2cmg)** (CVSS score: 10.0) - A patch bypass for CVE-2024-28185 that stems from the use of the UNIX [chown command](https://man7.org/linux/man-pages/man1/chown.1.html) on an untrusted file within the sandbox. An attacker can abuse this by creating a symbolic link (symlink) to a file outside the sandbox, allowing the attacker to run chown on arbitrary files outside of the sandbox.


* **[CVE-2024-29021](https://github.com/judge0/judge0/security/advisories/GHSA-q7vg-26pg-v5hr)** (CVSS score: 9.1) - The default configuration of Judge0 leaves the service vulnerable to a sandbox escape via Server-Side Request Forgery (SSRF). This allows an attacker with sufficient access to the Judge0 API to obtain unsandboxed code execution as root on the target machine.


The problem is rooted in a Ruby script named "[isolate\_job.rb](https://github.com/judge0/judge0/blob/master/app/jobs/isolate_job.rb)," which is responsible for setting up the sandbox, as well running the code and storing the results of the execution.


Specifically, it entails creating a symbolic link in the directory before a bash script is set up to execute the program based on the submission language such that it allows writing to an arbitrary file on the unsandboxed system.


A threat actor could leverage this flaw to overwrite scripts on the system and gain code execution outside of the sandbox and on the Docker container running the submission job.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj9LS2CMV85AM5f2fKKl2aPAnQ1iZEQKbHh7hRbW3rn3MowE5BXNOrNlHsrMYRMndplTjEmzciLAj6jVsDkRJI2IdSfFXSXuSlMn6gSgmzjKktBgyRTJsC-MayMQq8Z580Hjp8oCv0WoplbNRKlOEzR3RqajPwbLY2JzbQpwEIaW6u2UDkYmcWPO_Mmzq-X/s728-e365/cis-d.png)](https://thehackernews.uk/cis-controls-guide-sme)
What's more, the attacker could escalate their privileges outside of the Docker container due to it being run using the [privileged flag](https://docs.docker.com/compose/compose-file/build/#privileged) as specified in docker-compose.yml.


"This will allow the attacker to mount the Linux host filesystem and the attacker can then write files (for example a malicious cron job) to gain access to the system," Judge0's Herman Došilović said.


"From this point the attacker will have complete access to the Judge0 system including the database, internal networks, the Judge0 web server, and any other applications running on the Linux host."


CVE-2024-29021, on the other hand, has to do with a configuration that permits communicating with Judge0's PostgreSQL database available inside the internal Docker network, thus enabling the adversary to weaponize the SSRF to connect to the database and change the datatype of relevant columns and ultimately gain command injection.


Following responsible disclosure, the shortcomings have been addressed in [version 1.13.1](https://github.com/judge0/judge0/releases/tag/v1.13.1) released on April 18, 2024. Users of Judge0 are advised to update to the latest version to mitigate potential threats.


  





## Tags:
***CVE's***: CVE-2024-28185 CVE-2024-28189 CVE-2024-29021

### Autogenerated tags:
[[judge0]] [[cvss]]
