# When is One Vulnerability Scanner Not Enough?
## Are you confident your vulnerability scanner isn't leaving blind spots in your attack surface? Uncover the limitations of relying on a single scanner
## Information:

+ Link: https://thehackernews.com/2024/05/when-is-one-vulnerability-scanner-not.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 02 May 2024, 15:55
+ Date scraped: 02 May 2024, 11:08

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiKviT4De4sgrmOqC3LNheeaKAIrZWJxGjACpRDh6VAvwEPyULSveg4kb-r3O_bgfNbi31y0zWXGHa0wp8iHeFPzP8YLs06MFbln5o9zb4e3sbhDD2D_qQ2MUklFcmpdyGR1SOHTp-Ri7Xyr1zqJ1AD5ZDWyP7PejjY6iERNDuKJHmjWNxHHF_9p-2kssc/s1500/aa.png)


Like antivirus software, vulnerability scans rely on a database of known weaknesses.


That's why websites like VirusTotal exist, to give cyber practitioners a chance to see whether a malware sample is detected by multiple virus scanning engines, but this concept hasn't existed in the vulnerability management space.


The benefits of using multiple scanning engines [#](#the-benefits-of-using-multiple-scanning-engines)
-----------------------------------------------------------------------------------------------------


Generally speaking, vulnerability scanners aim to produce checks for as many vulnerabilities as possible. However, the number of vulnerabilities discovered year on year is now so high, reaching nearly 30,000 a year, or 80 a day, that it's impossible for a single scanning engine to keep up with them all.


As a result, even the very best, industry-leading leading scanners will struggle to check for every known vulnerability out there, and often they will favour certain sets of software known to be used by their customers.


For example, [Intruder's analysis](https://www.intruder.io/blog/openvas-vs-nessus?utm_source=thehackernews&utm_medium=p_referral&utm_campaign=global%7Cfixed%7Cnuclei) from early 2023 which compared Tenable's Nessus and OpenVAS showed significant differences in coverage between scanners, with one being generally stronger in commercial software, and the other favouring open source:


*"Tenable checks for 12,015 CVEs which OpenVAS does not check for and OpenVAS checks for 6,749 CVEs which Tenable does not check for."*


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiM5fI8sM9iPPRlHx223syT75obEIZ5UPz9SMKXxcPWeari1QYTpHYE6uPgGz_cTBEboDJloXa2hJLgK0ow0_7ICO9E_xR60yu9RK3ukTmKmO41ueYw_xRHv6qwjXIudGfBLhqWI3Wz2zpIjxh68s4ff-PZxpVBRynFY-_i-deDnT5RiCSEckNt5QE8YwY/s1500/image1.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiM5fI8sM9iPPRlHx223syT75obEIZ5UPz9SMKXxcPWeari1QYTpHYE6uPgGz_cTBEboDJloXa2hJLgK0ow0_7ICO9E_xR60yu9RK3ukTmKmO41ueYw_xRHv6qwjXIudGfBLhqWI3Wz2zpIjxh68s4ff-PZxpVBRynFY-_i-deDnT5RiCSEckNt5QE8YwY/s1500/image1.png)
Scanning engine vendors also take other factors into consideration, like whether a vulnerability has been exploited in the wild, or whether it's in software products which are very widely used. But even though your chosen scanner may be making sensible decisions on which vulnerabilities to write checks for there may still be gaps in coverage for your estate.


So it's a harsh reality that one day you may find out that you've been compromised via an attack vector which your vulnerability scanner simply doesn't have a check for.


This raises significant questions for those looking to protect their digital estates, not only which scanner they should choose. But whether one scanner is even enough?


The multi-scanning engine approach[#](#the-multiscanning-engine-approach)
-------------------------------------------------------------------------


It's clear that having several complementary scanners would improve coverage by finding more vulnerabilities, and discovering more about what your attack surface looks like. But operating multiple scanning systems would be too much for most organisations to afford, both in budget and time constraints.


That's why the team at Intruder, a leading [Attack Surface Management vendor](https://www.intruder.io/?utm_source=thehackernews&utm_medium=p_referral&utm_campaign=global%7Cfixed%7Cnuclei), decided from the start to incorporate multiple scanning engines, offering customers the widest breadth of checks, while streamlining budget and time constraints by providing them in a single platform.


Most recently, Intruder has added Nuclei to its suite of vulnerability scanning engines, enhancing its ability to manage and secure attack surfaces.


With over 3,000 additional checks in this initial release, Intruder can offer much broader and deeper coverage and discovery capabilities that can't be matched by using a single vulnerability scanner alone.


What is Nuclei?[#](#what-is-nuclei)
-----------------------------------


Nuclei is an open-source vulnerability scanning engine, similar to OpenVAS, which is fast, extensible, and covers a wide range of weaknesses. It's become increasingly popular with bug bounty hunters, penetration testers and researchers who want to produce repeatable checks for serious weaknesses.


These experts, working with the Nuclei development team at ProjectDiscovery, combine their knowledge and insights about cutting-edge weaknesses to produce checks extremely fast – which makes scanning as soon as possible after a vulnerability is discovered.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhjaiZhzhiVhn9JFTcCf80qAdv6VJF3uitHpJSsUxyoLc6ynrSHx_L2Qa0V0su1_ZivjKhXAJ0cubtmLjSvWpsFuSi-prOOYPW3iZwsVSWiIe3yrxoJo_xnqml7nOASjyABjbDFzkgL7o4GKZNpNeSsoGGM35m6G8N_zcAplDlhNEOJwto9Rh8Zc4yBJLk/s1500/image2.png)
**What does Nuclei add to Intruder?**


By integrating Nuclei as a scanning engine, Intruder further enhances its [vulnerability management platform](https://www.intruder.io/?utm_source=thehackernews&utm_medium=p_referral&utm_campaign=global%7Cfixed%7Cnuclei) capabilities to check and secure attack surfaces more effectively. 


This includes expanded detection of exposures like login panels that should not be exposed to the internet, and increasing the range of checks for known vulnerabilities in commonly exposed services.


Nuclei augments Intruder's existing scanning engines, such as Tenable and OpenVAS, by providing a deeper and broader view of your attack surface, thus enabling better protection by uncovering risks that would remain undetected by a single scanning engine.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEha3mVJJLp-5U_Vz5lsXvy6X9zqwMkaffmGa7YSZV2k4N1n6Iha8gN3TqVvrxFv6_CGGXkpPGjKQJeCYdyXTebIkl771ukn-umIT8rSlSkvKu9wmkIodmY7BWWqDxpg-ydWI3iiOjCHMrAz_IoPZHQ03wWQVvamI3F4WCe953hXrMFjxNqL9QMflOVPzBI/s1500/image3.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEha3mVJJLp-5U_Vz5lsXvy6X9zqwMkaffmGa7YSZV2k4N1n6Iha8gN3TqVvrxFv6_CGGXkpPGjKQJeCYdyXTebIkl771ukn-umIT8rSlSkvKu9wmkIodmY7BWWqDxpg-ydWI3iiOjCHMrAz_IoPZHQ03wWQVvamI3F4WCe953hXrMFjxNqL9QMflOVPzBI/s1500/image3.png)
Visualize and minimize your exposure with Intruder[#](#visualize-and-minimize-your-exposure-with-intruder)
----------------------------------------------------------------------------------------------------------


The size of your attack surface, and how well it's managed, is closely tied to your risk of opportunistic attackers exploiting your systems. The less you expose, and the more hardened the services you expose are, the harder it is for an attacker to exploit a weakness.


You can reduce your attack surface by continuously monitoring for changes with an automated vulnerability management tool like Intruder.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg8qvct4Q3MJ46zJRGd4YzWlau3jxmHRGQXCCt3YgEFXJICZl_mFSP0pG4msUVMhiJK4QaS_q_r0eBkIU299eoBYwk1CZlu_5lW2KjdqFRbuoP2YbVJ0V17KNK8J2owibFw5D5uomjGbIo7P_M4c50TzsD_82QU5h8TB008L-rAjHCV3vJJ9YK3mHqqv30/s1500/image34.png)
Intruder's platform allows you to:


* **Discover assets**: when new cloud services are spun up and exposed to the internet, Intruder kicks off a scan to find any vulnerabilities so you can fix them faster.
* **Know what's exposed**: get complete visibility of your network perimeter, track active and unresponsive targets, identify changes, monitor expiring certificates, and see any ports, services or protocols that shouldn't be exposed to the internet.
* **Detect more**: Intruder uses multiple scanners to identify vulnerabilities and exposures across your attack surface giving you the greatest visibility.
* **Focus on the big issues**: see results prioritized based on context, so you can focus on the most pressing problems without wasting time sifting through the noise.


  





## Tags:


### Autogenerated tags:
[[openvas]]
